Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(18)

Unified Diff: src/IceTargetLowering.h

Issue 870653002: Subzero: Initial implementation of multithreaded translation. (Closed) Base URL: https://chromium.googlesource.com/native_client/pnacl-subzero.git@master
Patch Set: Rebase Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/IceRegAlloc.cpp ('k') | src/IceTargetLowering.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/IceTargetLowering.h
diff --git a/src/IceTargetLowering.h b/src/IceTargetLowering.h
index 39fa5899ec8750585bc550de082647e8bb3515aa..49108fa843787d49c0d220b758f9ddf51458cb2a 100644
--- a/src/IceTargetLowering.h
+++ b/src/IceTargetLowering.h
@@ -199,8 +199,6 @@ public:
virtual void addProlog(CfgNode *Node) = 0;
virtual void addEpilog(CfgNode *Node) = 0;
- virtual void emitConstants() const = 0;
-
virtual ~TargetLowering() {}
protected:
@@ -242,23 +240,23 @@ protected:
LoweringContext Context;
};
-// TargetGlobalInitLowering is used for "lowering" global
-// initializers. It is separated out from TargetLowering because it
-// does not require a Cfg.
-class TargetGlobalInitLowering {
- TargetGlobalInitLowering(const TargetGlobalInitLowering &) = delete;
- TargetGlobalInitLowering &operator=(const TargetGlobalInitLowering &) =
- delete;
+// TargetGlobalLowering is used for "lowering" global initializers,
+// including the internal constant pool. It is separated out from
+// TargetLowering because it does not require a Cfg.
+class TargetGlobalLowering {
+ TargetGlobalLowering() = delete;
+ TargetGlobalLowering(const TargetGlobalLowering &) = delete;
+ TargetGlobalLowering &operator=(const TargetGlobalLowering &) = delete;
public:
- static TargetGlobalInitLowering *createLowering(TargetArch Target,
- GlobalContext *Ctx);
- virtual ~TargetGlobalInitLowering();
+ static TargetGlobalLowering *createLowering(GlobalContext *Ctx);
+ virtual ~TargetGlobalLowering();
- virtual void lower(const VariableDeclaration &Var) = 0;
+ virtual void lowerInit(const VariableDeclaration &Var) const = 0;
+ virtual void lowerConstants(GlobalContext *Ctx) const = 0;
protected:
- TargetGlobalInitLowering(GlobalContext *Ctx) : Ctx(Ctx) {}
+ TargetGlobalLowering(GlobalContext *Ctx) : Ctx(Ctx) {}
GlobalContext *Ctx;
};
« no previous file with comments | « src/IceRegAlloc.cpp ('k') | src/IceTargetLowering.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698